==> huaweicloudsdkgaussdb-3.1.100-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/single_node_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SingleNodeInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'node_id': 'node_id',
        'name': 'name'
    }

    def __init__(self, node_id=None, name=None):
        """SingleNodeInfo

        The model defined in huaweicloud sdk

        :param node_id: 节点ID。
        :type node_id: str
        :param name: 节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。
        :type name: str
        """
        
        

        self._node_id = None
        self._name = None
        self.discriminator = None

        self.node_id = node_id
        self.name = name

    @property
    def node_id(self):
        """Gets the node_id of this SingleNodeInfo.

        节点ID。

        :return: The node_id of this SingleNodeInfo.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this SingleNodeInfo.

        节点ID。

        :param node_id: The node_id of this SingleNodeInfo.
        :type node_id: str
        """
        self._node_id = node_id

    @property
    def name(self):
        """Gets the name of this SingleNodeInfo.

        节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。

        :return: The name of this SingleNodeInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SingleNodeInfo.

        节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。

        :param name: The name of this SingleNodeInfo.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SingleNodeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/single_node_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SingleNodeInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'node_id': 'node_id',
        'name': 'name'
    }

    def __init__(self, node_id=None, name=None):
        r"""SingleNodeInfo

        The model defined in huaweicloud sdk

        :param node_id: 节点ID。
        :type node_id: str
        :param name: 节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。
        :type name: str
        """
        
        

        self._node_id = None
        self._name = None
        self.discriminator = None

        self.node_id = node_id
        self.name = name

    @property
    def node_id(self):
        r"""Gets the node_id of this SingleNodeInfo.

        节点ID。

        :return: The node_id of this SingleNodeInfo.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        r"""Sets the node_id of this SingleNodeInfo.

        节点ID。

        :param node_id: The node_id of this SingleNodeInfo.
        :type node_id: str
        """
        self._node_id = node_id

    @property
    def name(self):
        r"""Gets the name of this SingleNodeInfo.

        节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。

        :return: The name of this SingleNodeInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this SingleNodeInfo.

        节点名称。支持中文、数字、字母、连接符-和_，长度为4-128。

        :param name: The name of this SingleNodeInfo.
        :type name: str
        """
        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SingleNodeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
